## livekit-plugins-chinese

为[livekit-agents](https://github.com/livekit/agents)**实时语音智能体**框架提供中文插件支持。


## plugins

| 厂商 | STT | TTS | LLM | 使用说明 |
| ---- | --- | --- | --- | --- |
| 火山引擎 | ✅  | ✅  | ✅  | [点击这里](livekit-plugins/livekit-plugins-volcengine) |
| 讯飞 | ✅  | ❎ | ❎ | [点击这里](livekit-plugins/livekit-plugins-xunfei) |
| 百度 | ✅  | ❎ | ❎ | [点击这里](livekit-plugins/livekit-plugins-baidu) |
| 腾讯 | ✅  | ❎ | ❎ | [点击这里](livekit-plugins/livekit-plugins-tencent) |
| Minimax | ❎ | ✅  | ❎ | [点击这里](livekit-plugins/livekit-plugins-minimax) |
| 智谱 | ❎ | ❎  | ✅  | [点击这里](livekit-plugins/livekit-plugins-zhipu) |
| Dify | ❎ | ❎  | ✅  | [点击这里](livekit-plugins/livekit-plugins-dify) |
| FlashTTS | ❎ | ✅  | ❎ | [点击这里](livekit-plugins/livekit-plugins-flashtts) |
| 阿里云 | ✅ | ✅  | ✅ | [点击这里](livekit-plugins/livekit-plugins-aliyun) |



## benchmark

TODO

